==> onos-yang-runtime-2.2.0-sources.jar: org/onosproject/yang/gen/v1/ietfl3vpnsvc/rev20160730/ietfl3vpnsvc/sitesecurityencryption/encryption/encryptionprofile/profile/DefaultCustomerProfile.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.sitesecurityencryption.encryption.encryptionprofile.profile;

import java.util.BitSet;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.sitesecurityencryption.encryption.encryptionprofile.Profile;
import org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.sitesecurityencryption.encryption.encryptionprofile.profile.customerprofile.KeyType;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of customerProfile.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultCustomerProfile extends InnerModelObject implements CustomerProfile {
    protected String algorithm;
    protected BitSet valueLeafFlags = new BitSet();
    protected KeyType keyType;

    @Override
    public String algorithm() {
        return algorithm;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public KeyType keyType() {
        return keyType;
    }

    @Override
    public void algorithm(String algorithm) {
        valueLeafFlags.set(LeafIdentifier.ALGORITHM.getLeafIndex());
        this.algorithm = algorithm;
    }

    @Override
    public void keyType(KeyType keyType) {
        this.keyType = keyType;
    }

    @Override
    public int hashCode() {
        return Objects.hash(algorithm, valueLeafFlags, keyType);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultCustomerProfile) {
            DefaultCustomerProfile other = (DefaultCustomerProfile) obj;
            return
                Objects.equals(algorithm, other.algorithm) &&
                Objects.equals(valueLeafFlags, other.valueLeafFlags) &&
                Objects.equals(keyType, other.keyType);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("algorithm=" + algorithm)
            .add("valueLeafFlags=" + valueLeafFlags)
            .add("keyType=" + keyType)
            .toString();
    }


    /**
     * Creates an instance of defaultCustomerProfile.
     */
    public DefaultCustomerProfile() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/ietfl3vpnsvc/rev20160730/ietfl3vpnsvc/sitesecurityencryption/encryption/encryptionprofile/profile/DefaultCustomerProfile.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.sitesecurityencryption.encryption.encryptionprofile.profile;

import java.util.BitSet;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.sitesecurityencryption.encryption.encryptionprofile.Profile;
import org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.sitesecurityencryption.encryption.encryptionprofile.profile.customerprofile.KeyType;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of customerProfile.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultCustomerProfile extends InnerModelObject implements CustomerProfile {
    protected String algorithm;
    protected BitSet valueLeafFlags = new BitSet();
    protected KeyType keyType;

    @Override
    public String algorithm() {
        return algorithm;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public KeyType keyType() {
        return keyType;
    }

    @Override
    public void algorithm(String algorithm) {
        valueLeafFlags.set(LeafIdentifier.ALGORITHM.getLeafIndex());
        this.algorithm = algorithm;
    }

    @Override
    public void keyType(KeyType keyType) {
        this.keyType = keyType;
    }

    @Override
    public int hashCode() {
        return Objects.hash(algorithm, valueLeafFlags, keyType);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultCustomerProfile) {
            DefaultCustomerProfile other = (DefaultCustomerProfile) obj;
            return
                Objects.deepEquals(algorithm, other.algorithm) &&
                Objects.deepEquals(valueLeafFlags, other.valueLeafFlags) &&
                Objects.deepEquals(keyType, other.keyType);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("algorithm=" + algorithm)
            .add("valueLeafFlags=" + valueLeafFlags)
            .add("keyType=" + keyType)
            .toString();
    }


    /**
     * Creates an instance of defaultCustomerProfile.
     */
    public DefaultCustomerProfile() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}
